#
# spec file for package font-util
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           font-util
Version:        1.4.1
Release:        1.2
Summary:        X.Org font package creation/installation utilities
License:        MIT
Group:          System/X11/Fonts
URL:            https://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/archive/individual/font/%{name}-%{version}.tar.xz
Source1:        http://xorg.freedesktop.org/archive/individual/font/%{name}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
Source3:        http://www.unicode.org/Public/MAPPINGS/VENDORS/MICSFT/WINDOWS/CP932.TXT
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
# Package was named xorg-x11-fonts-devel until 12.2
# We use 7.7 for Provides/Obsoletes, since we're renaming the packages when
# X11R7.7 is in RC1, and xorg-x11-fonts-devel was version 7.6
Provides:       xorg-x11-fonts-devel = 7.7
Obsoletes:      xorg-x11-fonts-devel < 7.7

%description
This package provides utilities for X.Org font package
creation/installation.

%prep
%setup -q
# see Bug 194720 for details
cp %{SOURCE3} map-JISX0201.1976-0

%build
%configure --with-mapdir=%{_datadir}/fonts/util --with-fontrootdir=%{_datadir}/fonts

%install
%make_install

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/bdftruncate
%{_bindir}/ucs2any
%{_mandir}/man1/bdftruncate.1%{?ext_man}
%{_mandir}/man1/ucs2any.1%{?ext_man}
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/fontutil.m4
%{_datadir}/fonts/util/
%{_libdir}/pkgconfig/fontutil.pc

%changelog
* Fri Sep  8 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.4.1
  * No functional changes - the map files have been updated to the
    ones currently available from the unicode website. This only
    changes the license preamble to SPDX Unicode-TOU, the actuali
    mappings are just the same as before.
* Thu Feb 23 2023 Stefan Dirsch <sndirsch@suse.com>
- Updage to version 1.4.0
  * This release updates the XORG_FONT_CHECK_COMPRESSION autoconf macro to
    also set a COMPRESS_FLAGS variable.
    By default, COMPRESS_FLAGS will be set to -n for gzip to stop recording
    timestamps to improve build reproducibility, and to empty for all other
    compression methods (compress, bzip2, or none).
    This will not be effective until the bdf font packages we produce are
    updated to add COMPRESS_FLAGS to Makefile.am, which will be occuring
    shortly.
* Tue Jul 12 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.3.3
  * ucs2any: avoid segfaults if SLANT property is missing
  * ucs2any: handle NULL returns from zquotedcpy()
  * gitlab CI: add a basic build test
  * Build xz tarballs instead of bzip2
  * Fix spelling/wording issues
* Mon Aug 26 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to font-util 1.3.2
  * This minor bugfix release fixes crashes of the ucs2any utility
    when faced with a poorly-formed bdf font file.
* Thu Aug  8 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Own %%{_datadir}/aclocal: when we might switch to pkgconf instead
  of pkg-config, nothing in the build root is 'accidentally' owning
  this directory for us.
* Wed Feb  8 2017 mstaudt@suse.com
- Set fontrootdir in configure options
  Fixes (boo#1024391).
* Sat Sep  5 2015 mpluskal@suse.com
- Add gpg signature
* Mon Mar 16 2015 sndirsch@suse.com
- Update to font-util 1.3.1:
  * This release fixes the autoconf macros installed for use
    generating the other Xorg font packages to respect the
    $PKG_CONFIG variable that some build systems, especially
    cross-compilers, require; and updates the license notice
    in map-JISX0201.1976-0 to the current version from Unicode
    Consortium.
* Fri Apr 25 2014 tobias.johannes.klausmann@mni.thm.de
- Remove superfluous BuildRequire, Require
* Tue Mar 26 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Wed May 16 2012 sndirsch@suse.com
- updated CP932.TXT to make buildservice happy
* Sun Apr 15 2012 vuntz@opensuse.org
- Rename source and binary package from xorg-x11-fonts-devel to
  font-utils.
- Add Provides/Obsoletes for xorg-x11-fonts-devel to smooth
  upgrades.
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to font-util 1.3.0:
  + bdftruncate: Properly support -w and +w
  + Fix compiler warnings
  + Better support for cross-compiling
- Include version of font-util in the version of the package. For
  instance, this will now be 7.6_1.3.0.
* Tue Dec 21 2010 sndirsch@novell.com
- bumped version number to 7.6
* Fri Oct 15 2010 sndirsch@novell.com
- font-util 1.2.0
  * This release adds two new options that some of the font
    packages will offer in their configure scripts:
  - -disable-all-encodings option to the macros used in the bdf
    font packages, to set the default to disabled for all
    encodings so that builders/packagers wanting to build just
    a subset of encodings can start with none and add the ones
    they want instead of having to disable all those they don't
    want.
  - -with-fc-confdir to specify the path to fontconfig's
    configuration files directory (normally /etc/fonts), for
    packages like bh-ttf that install fontconfig configuration
    snippets. If not specified, the default will be the confdir
    variable from fontconfig.pc if present (which it won't be
    until the next fontconfig release), otherwise
    ${sysconfdir}/fonts.
* Tue Oct  5 2010 sndirsch@novell.com
- font-util 1.1.2
  * This release fixes the bug in the fontutils.m4 autoconf macros
    that allowed packages generated with these macros to
    successfully pass configure when required utilities were
    missing, resulting in build failures that were hard to
    diagnose, such as "-b: command not found".
    Existing font packages will need to have autoreconf run after
    installing the new fontutil.m4 to take advantage of this fix -
    the next release of the font packages will include this fix in
    the configure scripts distributed in their tarballs.
* Fri Apr  2 2010 sndirsch@suse.de
- bumped version number to 7.5
* Wed Mar 17 2010 ro@suse.de
- font-util 1.1.1
* Sat Aug  8 2009 sndirsch@suse.de
- font-util 1.0.2
  * Replace bdftruncate Perl script with C program
* Thu Sep 11 2008 sndirsch@suse.de
- bumped release number to 7.4
* Mon Jan 21 2008 sndirsch@suse.de
- no longer mark sources as NoSource (new policy)
* Sat Sep 29 2007 sndirsch@suse.de
- bumped version to 7.3
* Thu Oct 26 2006 sndirsch@suse.de
- set version to 7.2 in specfile
* Wed Aug  9 2006 sndirsch@suse.de
- fixed /usr/share/fonts directory conflict with filesystem
* Wed Aug  2 2006 sndirsch@suse.de
- fix setup line
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- switched from JIS0201 to CP932 due to legal issues (Bug #194720)
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
* Thu Jun 29 2006 sndirsch@suse.de
- created package
